==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
var WebForOfStateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateEventArgsDescriptionMetadata, _super);
    function WebForOfStateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
            WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebForOfStateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebForOfStateEventArgsDescriptionMetadata.a);
        WebForOfStateDetailDescriptionMetadata.d(a);
    };
    WebForOfStateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
        a.item("Detail", "ExportedType:WebForOfStateDetail");
    };
    WebForOfStateEventArgsDescriptionMetadata.d = function (a) {
        WebForOfStateEventArgsDescriptionMetadata.b(a);
        a.aa("WebForOfStateEventArgs", function () { return new WebForOfStateEventArgsDescription(); });
        a.z("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
    };
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
}(Base));
export { WebForOfStateEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebForOfStateEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebForOfStateDetailDescriptionMetadata } from "./WebForOfStateDetailDescriptionMetadata";
import { WebForOfStateEventArgsDescription } from "./WebForOfStateEventArgsDescription";
/**
 * @hidden
 */
var WebForOfStateEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebForOfStateEventArgsDescriptionMetadata, _super);
    function WebForOfStateEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebForOfStateEventArgsDescriptionMetadata.b = function (a) {
        if (WebForOfStateEventArgsDescriptionMetadata.a == null) {
            WebForOfStateEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebForOfStateEventArgsDescriptionMetadata.c(WebForOfStateEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebForOfStateEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebForOfStateEventArgsDescriptionMetadata.a);
        WebForOfStateDetailDescriptionMetadata.d(a);
    };
    WebForOfStateEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ForOfStateEventArgs");
        a.item("Detail", "ExportedType:WebForOfStateDetail");
    };
    WebForOfStateEventArgsDescriptionMetadata.d = function (a) {
        WebForOfStateEventArgsDescriptionMetadata.b(a);
        a.ac("WebForOfStateEventArgs", function () { return new WebForOfStateEventArgsDescription(); });
        a.ab("WebForOfStateEventArgs", WebForOfStateEventArgsDescriptionMetadata.a);
    };
    WebForOfStateEventArgsDescriptionMetadata.$t = markType(WebForOfStateEventArgsDescriptionMetadata, 'WebForOfStateEventArgsDescriptionMetadata');
    WebForOfStateEventArgsDescriptionMetadata.a = null;
    return WebForOfStateEventArgsDescriptionMetadata;
}(Base));
export { WebForOfStateEventArgsDescriptionMetadata };
